Get Started
===========

Installation
************

pymeasurement is distributed on `PyPi <https://pypi.org/project/pymeasurement/>`_. 

To get started, you need to install the following:

.. code:: bash

    pip install pymeasurement


First Steps
***********

.. code:: python

    from pymeasurement import Measurement as M

    print(M.fromStr("1.2 +/- 0.1 m"))


Congrats, you are now ready to use pymeasurement! Read on in the user guide for more examples.